"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformImg = void 0;
const picgo_1 = __importDefault(require("picgo"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const log_1 = require("../log");
let picgo = null;
const helpUpload = (imgConfig, imgs) => {
    const p = new Promise((resolve) => {
        if (!picgo) {
            picgo = new picgo_1.default(imgConfig).on('finished', (ctx) => {
                const res = ctx.output.reduce((map, item, index) => {
                    map[imgs[index]] = item.imgUrl;
                    return map;
                }, {});
                resolve(res);
            });
            picgo.helper.beforeUploadPlugins.register('rename', {
                handle: function (ctx) {
                    ctx.output.forEach((x) => {
                        return (x.fileName = x.fileName + Date.now());
                    });
                },
            });
        }
        picgo.upload(imgs);
    });
    return p;
};
const transformImg = function (files) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        const imgConfig = this.config.imgConfig;
        if (!imgConfig) {
            return;
        }
        log_1.info('转存图片开始');
        const map = new Map();
        // 获取图片地址
        for (let file of files) {
            const content = fs_extra_1.default.readFileSync(file, 'utf8');
            const urls = (_a = content.match(/\!\[.*\]\(.*\)/g)) === null || _a === void 0 ? void 0 : _a.map((i) => {
                const url = i.match(/\!\[.*\]\((.*?)( ".*")?\)/)[1];
                return url;
            });
            if (urls) {
                map.set(file, urls);
            }
        }
        const upload = [];
        for (let l of map.values()) {
            upload.push(...l);
        }
        const originNewMap = Object.create(null);
        // 每次传5张。串行传
        log_1.info(`开始转存图片，共${upload.length}张`);
        let length = 2;
        for (let i = 0; i < upload.length; i += length) {
            try {
                const result = yield helpUpload(this.config.imgConfig, upload.slice(i, i + length));
                Object.assign(originNewMap, result);
            }
            catch (e) {
                console.log(e);
            }
        }
        // 替换图片
        for (let file of files) {
            let content = fs_extra_1.default.readFileSync(file, 'utf8');
            const urls = (_b = content.match(/\!\[.*\]\(.*\)/g)) === null || _b === void 0 ? void 0 : _b.map((i) => {
                const url = i.match(/\!\[.*\]\((.*?)( ".*")?\)/)[1];
                return url;
            });
            urls.forEach((url) => {
                if (originNewMap[url]) {
                    content = content.replace(new RegExp(url, 'g'), originNewMap[url]);
                }
            });
            fs_extra_1.default.writeFileSync(file, content);
        }
    });
};
exports.transformImg = transformImg;
//# sourceMappingURL=transformImg.js.map